globalVariables(unique(c(
  # .calc_rci_en:
  "deteriorated", "id", "improved", "lower", "post", "pre", "pre_true", "unchanged", "upper",
  # .calc_rci_gln:
  "change_adj", "post_adj", "pre_adj",
  # .calc_rci_ha:
  "post", "pre",
  # .calc_rci_hll:
  "change_adj", "post", "post_adj", "pre", "pre_adj",
  # .calc_rci_hlm:
  "condsd", "condval", "eb_estimate", "grp", "id", "term", "value",
  # .calc_rci_jt:
  "change",
  # .calc_rci_nk:
  "change_adj", "post", "pre", "pre_adj",
  # .calc_cutoff_ha_data:
  "cs_indiv", "functional_post",
  # .calc_cutoff_jt_data:
  "clinical_pre", "functional_post",
  # .calc_improvement:
  "rci",
  # .calc_recovered:
  "clinical_pre", "functional_post", "harmed", "recovered",
  # .calc_recovered_ha:
  "cs_indiv", "functional_post", "rci", "recovered",
  # .create_summary_table:
  "category", "harmed", "recovered",
  # .create_summary_table_ha:
  "category", "changed", "functional", "m_post", "mean_change", "sd_change", "z_changed", "z_functional",
  # get_augmented_data:
  "category",
  # get_cutoff:
  "type",
  # get_cutoff_descriptives:
  "type",
  # get_n:
  "n_original", "n_used",
  # plot.clinisig:
  "outcome", "time", "ymax", "ymin",
  # summary.clinisig:
  "m_clinical", "m_functional", "reliability_clinical", "reliability_functional", "sd_clinical", "sd_functional",
  # pot:
  "group",
  # .prep_data:
  "n",
  # calc_anchor.cs_anchor_group_between:
  "comparison", "reference", "results",
  # calc_anchor.cs_anchor_group_within:
  "results",
  # calc_cutoff_from_data.cs_ha:
  "clinical_post",
  # calc_percentage:
  "pct_change",
  # create_summary_table.cs_anchor_individual_within:
  "n",
  # create_summary_table.cs_combined:
  "n",
  # create_summary_table.cs_distribution:
  "n",
  # create_summary_table.cs_percentage:
  "n",
  # create_summary_table.cs_statistical:
  "clinical_post", "n",
  # plot.cs_anchor_group_between:
  "comparison", "difference",
  # plot.cs_anchor_group_within:
  "difference",
  # t_test_between:
  "CI", "CI_high", "CI_low", "Median",
  # t_test_within:
  "CI", "CI_high", "CI_low", "Median",
  # calc_rci.cs_hlm:
  "sd"
)))
